﻿define("frontifyintegration/editors/FrontifyThumbnailSelector", [
    // dojo
    "dojo/_base/declare",
    "dojo/when",
    "dojo/on",
    "dojo/topic",
    "dojo/dom-class",
    "dojo/ready",
    "dojo/_base/lang",
    // dijit
    "dijit/focus",
    "dijit/ProgressBar",
    // epi
    "epi/Url",
    "epi/routes",
    "epi/shell/dnd/Target",
    "epi/shell/DialogService",
    "epi/shell/XhrWrapper",
    // epi-cms
    "epi-cms/core/ContentReference",
    "epi-cms/widget/MediaSelector",
    "epi-cms/widget/ThumbnailSelector",
    "epi-cms/command/UploadContent",
    "epi-cms/widget/UploadUtil",
    "epi-cms/widget/viewmodel/MultipleFileUploadViewModel",
    "epi-cms/widget/LocalFolderUploader",
    "dojo/text!./templates/FrontifyThumbnailSelector.html",
    "epi-cms/legacy/LegacyDialogPopup",
    "epi/i18n!epi/cms/nls/episerver.cms.widget.thumbnailselector"
], function (
    // dojo
    declare,
    when,
    on,
    topic,
    domClass,
    ready,
    lang,
    // dijit
    focusManager,
    ProgressBar,
    // epi
    Url,
    routes,
    Target,
    dialogService,
    XhrWrapper,
    // epi-cms
    ContentReference,
    MediaSelector,
    ThumbnailSelector,
    UploadContent,
    UploadUtil,
    MultipleFileUploadViewModel,
    LocalFolderUploader,
    template,
    LegacyDialogPopup,
    resources
) {
        var xhr = new XhrWrapper();
        return declare([ThumbnailSelector], {
            // summary:
            //      Represents the widget to select ContentReference.
            // tags:
            //      internal

            resources: resources,
            templateString: template,

            loaded: false,
            uploadDisabledMessage: "Drag and drop feature has been disabled, please use Frontify.",
            frontifypath: null,
            frontifyiconpath: null,
            frontifytenanturl: null,
            frontifymodulepath: null,
            frontifyapitoken: null,
            frontifyallowedfiletypes: null,
            frontifychoosermode: null,

            fwWin: null,
            timer: null,
            pluginurl: null,
            disableMediaSelector: null,
            listenerBound: false,
            allowedExtensions: [],
            postCreate: function () {

                ready(setTimeout(lang.hitch(this, function () {//not optimal with timeout, but else not working with _setValue when used on init
                    this.loaded = true;
                }), 100));

                this.allowedExtensions = this.frontifyallowedfiletypes.replace(".", "").replace(/,/gi, "").split('.');

                this.inherited(arguments);
            },
            getFetchCf: function (url, data) {
                var self = this;
                return xhr.xhrGet({
                    url: url,
                    content: data,
                    failOk: true,
                    error: function(response) {
                        self._dialogService.alert(response.responseText);
                    }
                });
            },
            // Custom function for Frontify integration to trigger opening of dialog.
            _onFrontifyButtonClick: function () {

                this.pluginurl = this.frontifypath + "ClientResources/plugin/frontify.html?frontifyUrl=" +
                    this.frontifytenanturl +
                    "&";

                this.fwWin  = new LegacyDialogPopup({
                    url: this.pluginurl + Math.random(),
                    onCallback: null,
                    dialogArguments: {},
                    dialogTitle: "Frontify Asset Chooser (" + this.frontifyallowedfiletypes + ")",
                    autoFit: false,
                    showCancelButton: true,
                    showLoadingOverlay: false,
                    features: {width:1200,height:900}
                });
                this.fwWin.actionContainerNode.hidden = true;
                this.fwWin.show();

                if (!this.listenerBound) {
                    this._listener = this._listener.bind(this);
                    window.addEventListener("message", this._listener, true);
                    this.listenerBound = true;
                }

               this.timer = setInterval(lang.hitch(this,
                        function() {
                            if (!this.fwWin.open) {
                                window.removeEventListener("message", this._listener, true);
                                this.listenerBound = false;
                                clearInterval(this.timer);
                                return;
                            }
                        }),
                    2000);

            },
            _listener: function (event) {
                if (event.data!==null) {//check if message is for this property
                    //take care of tokenRequested when iframe is loaded
                    if (event.data.configurationRequested) {
                        var fileTypes = this.frontifyallowedfiletypes.replace(".", "").replace(/,/gi, "").split('.');
                        this.fwWin.wrapper.containerIframe.contentWindow.postMessage({
                            "token": this.frontifyapitoken,
                            multiSelectionAllowed: false,
                            mode: this.frontifychoosermode,
                            fileTypes: fileTypes
                        }, location.origin);
                        return; //stop
                    } else if (event.data.aborted) {
                        //remove listener
                        window.removeEventListener("message", this._listener, true);
                        this.listenerBound = false;
                        this.fwWin.hide();
                    } else if (event.data.assetsChosen) {
                        if (event.data.assetsChosen.length > 0) {
                            this.fwWin.hide();
                            //remove listener
                            window.removeEventListener("message", this._listener, true);
                            this.listenerBound = false;

                            var self = this;
                            when(self.getFetchCf(
                                    self.frontifymodulepath + "authentication/fetchcf",
                                    {
                                        hostcontent: "",
                                        imageid: event.data.assetsChosen[0].id,
                                        ext: event.data.assetsChosen[0].ext,
                                        projectid: event.data.assetsChosen[0].project,
                                        allowedfiletypes: self.frontifyallowedfiletypes
                                    }),
                                function (data) {
                                    self._setValueAndFireOnChange(data + "");
                                });
                        }
                    }
                }
            },

            _updateDisplayNode: function (content) {
                this.inherited(arguments);
                if (content) {
                    this.thumbnail.src = this._getThumbnailUrl(content).toString();
                    //custom thumbnail
                    if (!content.name.match(/.(jpg|jpeg|png|gif|bmp|jpe)$/i)) {
                        this.thumbnail.src = this.frontifymodulepath + "authentication/GenerateThumb?contentid=" + content.contentLink;
                        this.thumbnail.style = "object-fit:contain;";
                    }
                }
                this.stateNode.title = content ? content.name : "";
            },


            _setValueAttr: function (value) {
                if (this.disableMediaSelector && this.loaded && value != null) {
                    this._dialogService.alert(this.uploadDisabledMessage);
                    return;
                }
                this.inherited(arguments);
            },

            _onButtonClick: function () {
                if (this.readOnly) {
                    return;
                }

                if (this.disableMediaSelector) {
                    this._onFrontifyButtonClick();
                    return;
                }


                this.inherited(arguments);
            }
        });
    });
