﻿"use strict";

/*
 * Simple proxy script that redirects incoming messages
 * to Frontify through an iframe. Message replies are
 * redirected back to caller.
 */

document.addEventListener('DOMContentLoaded',
    function (event) {

        checkConfig();
        var iframe = document.getElementById('mainframe');

        // get Frontify origin/URL from query string
        var ivOrigin = getQueryStringParameterByName('frontifyUrl');
        //debugger;
        // if no frontifyUrl, use default 'error.html'
        if (!ivOrigin || ivOrigin.length == 0) {

            ivOrigin = 'error.html';
        }

        // set iframe to Frontify origin with query string, but not need
        iframe.src = ivOrigin

        // Make sure target origin does not have trailing slash
        if (ivOrigin.slice(-1) === '/') {
            ivOrigin = ivOrigin.slice(0, -1);
        }

        // polyfill for location.origin
        if (typeof location.origin === 'undefined') {
            location.origin = location.protocol + '//' + location.host;
        }

        // Message received and sender will be the same.
        if (ivOrigin.indexOf('/') === 0) {
            ivOrigin = location.origin;
        }

        // init messaging
        window.addEventListener('message', messageEvent);

        /*
         * Handle message events.
         *
         * Forwards from opener to Frontify or returns from Frontify to opener.
         */
        function messageEvent(message) {
            if (verifyInputMessage(message)) {
                
                // forward message -> to Frontify
                iframe.contentWindow.postMessage(message.data, ivOrigin);
            } else {
                // reply to opener <- from Frontify
                window.opener.postMessage(message.data, location.origin);
            }
        }

        /*
         * Verifies a message as input to Frontify:
         * Check that message origin is from us and make sure the message data is a valid input command.
         */
        function verifyInputMessage(message) {
            return message.origin === location.origin;
        }

        /*
         * Helper method to get specific query parameter from querystring
         */
        function getQueryStringParameterByName(name) {
            const url = window.location.href;
            name = name.replace(/[\[\]]/g, '\\$&');
            const regex = new RegExp('[?&]' + name + '(=([^&#]*)|&|#|$)');
            const results = regex.exec(url);

            if (!results) {
                return null;
            }

            if (!results[2]) {
                return '';
            }

            return decodeURIComponent(results[2].replace(/\+/g, ' '));
        }
    });

function checkConfig() {
    ajax("../../../authentication/checkvalidconfig",
        null,
        function(e) {
            console.error(e);
            document.write(e.responseText);
            //window.close();
        });
}

function ajax(url, successFunc, errFunc) {
    var xhttp;
    xhttp = new XMLHttpRequest();
    xhttp.onreadystatechange = function () {
        if (this.readyState == 4 && this.status == 200 && successFunc!=null) {
            successFunc(this);
        }
        if (this.readyState == 4 && this.status != 200) {
            errFunc(this);
        }
    };
    xhttp.open("GET", url, true);
    xhttp.send();
}

