﻿using System;
using EPiServer;
using EPiServer.Cms.Shell;
using EPiServer.Core;
using EPiServer.ServiceLocation;
using EPiServer.Web;
using EPiServer.Web.Routing;

namespace Frontify.Episerver.Plugin.tinymce

{
    //[ServiceConfiguration(typeof(IFrontifyTinyMceTemplateResolver))]
    // Example of FrontifyTinyMceTemplateResolver implementation for Tiny MCE insertion.
    // Implement and register your custom instance in the IOC container to override default behaviour.

    public class FrontifyTinyMceTemplateResolver : IFrontifyTinyMceTemplateResolver
    {
        private readonly IContentRepository _contentRepository;
        private readonly UrlResolver _urlResolver;
        private readonly TemplateResolver _templateResolver;

        public FrontifyTinyMceTemplateResolver(IContentRepository contentRepository, UrlResolver urlResolver, TemplateResolver templateResolver)
        {
            _contentRepository = contentRepository;
            _urlResolver = urlResolver;
            _templateResolver = templateResolver;
        }
        /// <summary>
        /// By overriding, building a custom html image template to frontify insert in tinymce
        /// </summary>
        /// <param name="contentReference">What image to use</param>
        /// <param name="insertingToContentReference">if you want to do some custom html depending on type of block or pag</param>
        /// <returns>Some custom imagetag</returns>
        public string GetHtml(ContentReference contentReference, string insertingToContentReference = null)
        {
            var content = _contentRepository.Get<IContent>(contentReference);

            //if you want to do some custom html depending on type of block or page
            if (!String.IsNullOrEmpty(insertingToContentReference))
            {
                int id = int.Parse(insertingToContentReference.Split(new char[] { '_' })[0]);//Support for versions.
                ContentReference insertinto = new ContentReference(id);
            }

            if (content is ImageData)
            {
                var desc = content.Property["Description"] != null ? content.Property["Description"].Value : "";
                var url = content.PreviewUrl(this._urlResolver, this._templateResolver);
                return $"<img src=\'{url}\' class=\'frontify-img\' alt=\'{desc}\'/>";
            }
            else if (content is MediaData)
            {
                var desc = content.Property["Description"] != null ? content.Property["Description"].Value : "";
                var url = content.PreviewUrl(this._urlResolver, this._templateResolver);
                return $"<a href=\'{url}\' class=\'frontify-asset\' title=\'{desc}\'>{content.Name}</a>";
            }
            else
                return "Content type not valid";
        }
    }

    interface IFrontifyTinyMceTemplateResolver
    {
        string GetHtml(ContentReference contentReference, string insertingToContentReference = null);
    }
}